==> ccaPP_0.1.1.tar.gz: ccaPP/man/ccaProj.Rd <==
\name{ccaProj}
\alias{ccaProj}
\alias{CCAproj}
\title{(Robust) CCA via projections through the data points}
\usage{
  ccaProj(x, y, k = 1,
    method = c("spearman", "kendall", "quadrant", "M", "pearson"),
    control = list(...), useL1Median = TRUE, ...)

  CCAproj(x, y, k = 1,
    method = c("spearman", "kendall", "quadrant", "M", "pearson"),
    useL1Median = TRUE, ...)
}
\arguments{
  \item{x,y}{each can be a numeric vector, matrix or data
  frame.}

  \item{k}{an integer giving the number of canonical
  variables to compute.}

  \item{method}{a character string specifying the
  correlation functional to maximize.  Possible values are
  \code{"spearman"} for the Spearman correlation,
  \code{"kendall"} for the Kendall correlation,
  \code{"quadrant"} for the quadrant correlation,
  \code{"M"} for the correlation based on a bivariate
  M-estimator of location and scatter with a Huber loss
  function, or \code{"pearson"} for the classical Pearson
  correlation (see \code{\link{corFunctions}}).}

  \item{control}{a list of additional arguments to be
  passed to the specified correlation functional.  If
  supplied, this takes precedence over additional arguments
  supplied via the \code{\dots} argument.}

  \item{useL1Median}{a logical indicating whether the
  \eqn{L_{1}}{L1} medians should be used as the centers of
  the data sets (defaults to \code{TRUE}).  If
  \code{FALSE}, the columnwise centers are used instead
  (columnwise means if \code{method} is \code{"pearson"}
  and columnwise medians otherwise).}

  \item{\dots}{additional arguments to be passed to the
  specified correlation functional.}
}
\value{
  An object of class \code{"cca"} with the following
  components:

  \item{cor}{a numeric vector giving the canonical
  correlation measures.}

  \item{A}{a numeric matrix in which the columns contain
  the canonical vectors for \code{x}.}

  \item{B}{a numeric matrix in which the columns contain
  the canonical vectors for \code{y}.}

  \item{call}{the matched function call.}
}
\description{
  Perform canoncial correlation analysis via projection
  pursuit based on projections through the data points,
  with a focus on robust and nonparametric methods.
}
\details{
  First the candidate projection directions are defined for
  each data set from the respective center through each
  data point.  Then the algorithm scans all \eqn{n^2}
  possible combinations for the maximum correlation, where
  \eqn{n} is the number of observations.
}
\note{
  \code{CCAproj} is a simple wrapper function for
  \code{ccaProj} for more compatibility with package
  \pkg{pcaPP} concerning function names.
}
\examples{
## generate data
library("mvtnorm")
set.seed(1234)  # for reproducibility
p <- 3
q <- 2
m <- p + q
sigma <- 0.5^t(sapply(1:m, function(i, j) abs(i-j), 1:m))
xy <- rmvnorm(100, sigma=sigma)
x <- xy[, 1:p]
y <- xy[, (p+1):m]

## Spearman correlation
ccaProj(x, y, method = "spearman")
ccaProj(x, y, method = "spearman", consistent = TRUE)

## Pearson correlation
ccaProj(x, y, method = "pearson")
}
\author{
  Andreas Alfons
}
\seealso{
  \code{\link{ccaGrid}} \code{\link{corFunctions}}
}
\keyword{multivariate}
\keyword{robust}

==> ccaPP_0.2.0.tar.gz: ccaPP/man/ccaProj.Rd <==
\name{ccaProj}
\alias{ccaProj}
\alias{CCAproj}
\title{(Robust) CCA via projections through the data points}
\usage{
  ccaProj(x, y, k = 1,
    method = c("spearman", "kendall", "quadrant", "M", "pearson"),
    control = list(...), useL1Median = TRUE,
    fallback = FALSE, ...)

  CCAproj(x, y, k = 1,
    method = c("spearman", "kendall", "quadrant", "M", "pearson"),
    useL1Median = TRUE, fallback = FALSE, ...)
}
\arguments{
  \item{x,y}{each can be a numeric vector, matrix or data
  frame.}

  \item{k}{an integer giving the number of canonical
  variables to compute.}

  \item{method}{a character string specifying the
  correlation functional to maximize.  Possible values are
  \code{"spearman"} for the Spearman correlation,
  \code{"kendall"} for the Kendall correlation,
  \code{"quadrant"} for the quadrant correlation,
  \code{"M"} for the correlation based on a bivariate
  M-estimator of location and scatter with a Huber loss
  function, or \code{"pearson"} for the classical Pearson
  correlation (see \code{\link{corFunctions}}).}

  \item{control}{a list of additional arguments to be
  passed to the specified correlation functional.  If
  supplied, this takes precedence over additional arguments
  supplied via the \code{\dots} argument.}

  \item{useL1Median}{a logical indicating whether the
  \eqn{L_{1}}{L1} medians should be used as the centers of
  the data sets (defaults to \code{TRUE}).  If
  \code{FALSE}, the columnwise centers are used instead
  (columnwise means if \code{method} is \code{"pearson"}
  and columnwise medians otherwise).}

  \item{fallback}{logical; if a correlation functional
  other than the Pearson correlation is maximized, the data
  are first robustly standardized via median and MAD.  This
  indicates whether standardization via mean and standard
  deviation should be performed as a fallback mode for
  variables whose MAD is zero (e.g., for dummy variables).
  Note that if the Pearson correlation is maximized, the
  data are always standardized via mean and standard
  deviation.}

  \item{\dots}{additional arguments to be passed to the
  specified correlation functional.  Currently, this is
  only relevant for the M-estimator.  For Spearman, Kendall
  and quadrant correlation, consistency at the normal model
  is always forced.}
}
\value{
  An object of class \code{"cca"} with the following
  components:

  \item{cor}{a numeric vector giving the canonical
  correlation measures.}

  \item{A}{a numeric matrix in which the columns contain
  the canonical vectors for \code{x}.}

  \item{B}{a numeric matrix in which the columns contain
  the canonical vectors for \code{y}.}

  \item{call}{the matched function call.}
}
\description{
  Perform canoncial correlation analysis via projection
  pursuit based on projections through the data points,
  with a focus on robust and nonparametric methods.
}
\details{
  First the candidate projection directions are defined for
  each data set from the respective center through each
  data point.  Then the algorithm scans all \eqn{n^2}
  possible combinations for the maximum correlation, where
  \eqn{n} is the number of observations.
}
\note{
  \code{CCAproj} is a simple wrapper function for
  \code{ccaProj} for more compatibility with package
  \pkg{pcaPP} concerning function names.
}
\examples{
## generate data
library("mvtnorm")
set.seed(1234)  # for reproducibility
p <- 3
q <- 2
m <- p + q
sigma <- 0.5^t(sapply(1:m, function(i, j) abs(i-j), 1:m))
xy <- rmvnorm(100, sigma=sigma)
x <- xy[, 1:p]
y <- xy[, (p+1):m]

## Spearman correlation
ccaProj(x, y, method = "spearman")

## Pearson correlation
ccaProj(x, y, method = "pearson")
}
\author{
  Andreas Alfons
}
\seealso{
  \code{\link{ccaGrid}}, \code{\link{maxCorProj}},
  \code{\link{corFunctions}}
}
\keyword{multivariate}
\keyword{robust}
